"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.findMedia = exports.setMedia = void 0;

var _get = _interopRequireDefault(require("lodash/get"));

var _config = _interopRequireDefault(require("../config"));

var _reducers = require("../reducers");

var _actionCodes = require("../constants/actionCodes");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* global fetch */
const setMedia = (referenceValue, institutionId, mediaCsids, mediaAltTexts) => ({
  type: _actionCodes.SET_MEDIA,
  payload: {
    csids: mediaCsids,
    altTexts: mediaAltTexts
  },
  meta: {
    institutionId,
    referenceValue
  }
});

exports.setMedia = setMedia;

const findMedia = (referenceValue, institutionId) => (dispatch, getState) => {
  if ((0, _reducers.getMedia)(getState(), referenceValue, institutionId)) {
    return Promise.resolve();
  }

  let gatewayUrl;

  if (institutionId === null) {
    gatewayUrl = _config.default.get('gatewayUrl');
  } else {
    gatewayUrl = _config.default.get(['institutions', institutionId, 'gatewayUrl']);
  }

  const url = `${gatewayUrl}/es/doc/_search`;

  const referenceField = _config.default.get('referenceField');

  const query = {
    _source: ['collectionspace_denorm:mediaCsid', 'collectionspace_denorm:mediaAltText'],
    query: {
      term: {
        [referenceField]: referenceValue
      }
    },
    size: 1,
    terminate_after: 1
  };
  return fetch(url, {
    method: 'POST',
    headers: {
      'Content-Type': 'application/json'
    },
    body: JSON.stringify(query)
  }).then(response => response.json()).then(data => {
    const source = (0, _get.default)(data, ['hits', 'hits', 0, '_source']);
    const mediaCsids = (0, _get.default)(source, 'collectionspace_denorm:mediaCsid') || [];
    const mediaAltTexts = (0, _get.default)(source, 'collectionspace_denorm:mediaAltText') || [];
    return dispatch(setMedia(referenceValue, institutionId, mediaCsids, mediaAltTexts));
  });
};

exports.findMedia = findMedia;