"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactIntl = require("react-intl");

var _cspaceRefname = require("cspace-refname");

var _immutable = _interopRequireDefault(require("immutable"));

var _urlHelpers = require("../../../helpers/urlHelpers");

var _config = _interopRequireDefault(require("../../../config"));

var _SearchResultImage = _interopRequireDefault(require("../../../../styles/cspace/SearchResultImage.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/* global fetch, AbortController */
const propTypes = {
  gatewayUrl: _propTypes.default.string.isRequired,
  holdingInstitutions: _propTypes.default.instanceOf(_immutable.default.List),
  mediaCsid: _propTypes.default.string,
  referenceValue: _propTypes.default.string.isRequired
};
const defaultProps = {
  holdingInstitutions: _immutable.default.List(),
  mediaCsid: undefined
};
const messages = (0, _reactIntl.defineMessages)({
  noimage: {
    "id": "searchResultImage.noimage",
    "defaultMessage": "no image available"
  }
});

class SearchResultImage extends _react.Component {
  constructor(props) {
    super();
    this.state = {
      gatewayUrl: props.gatewayUrl,
      mediaCsid: props.mediaCsid
    };

    if (AbortController) {
      this.abortController = new AbortController();
    }
  }

  componentDidMount() {
    const {
      holdingInstitutions,
      mediaCsid,
      referenceValue
    } = this.props;
    this.init(referenceValue, mediaCsid, holdingInstitutions);
  }

  componentDidUpdate(prevProps) {
    const {
      gatewayUrl: prevGatewayUrl,
      mediaCsid: prevMediaCsid,
      referenceValue: prevReferenceValue
    } = prevProps;
    const {
      holdingInstitutions,
      gatewayUrl,
      mediaCsid,
      referenceValue
    } = this.props;

    if (mediaCsid !== prevMediaCsid || gatewayUrl !== prevGatewayUrl || referenceValue !== prevReferenceValue) {
      // FIXME: Make this component stateless.
      // eslint-disable-next-line react/no-did-update-set-state
      this.setState({
        gatewayUrl,
        mediaCsid
      });
      this.init(referenceValue, mediaCsid, holdingInstitutions);
    }
  }

  componentWillUnmount() {
    if (this.abortController) {
      this.abortController.abort();
    }
  }

  getMediaCsid(gatewayUrl, indexName, referenceValue) {
    const url = `${gatewayUrl}/es/doc/_search`;

    const referenceField = _config.default.get('referenceField');

    const query = {
      _source: 'collectionspace_denorm:mediaCsid',
      query: {
        term: {
          [referenceField]: referenceValue
        }
      },
      size: 1,
      terminate_after: 1
    };
    return fetch(url, {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json'
      },
      body: JSON.stringify(query),
      signal: this.abortController ? this.abortController.signal : undefined
    }).then(response => response.json()) // eslint-disable-next-line no-underscore-dangle
    .then(data => data.hits.hits[0]._source['collectionspace_denorm:mediaCsid'][0]).catch(() => undefined);
  }

  init(referenceValue, mediaCsid, holdingInstitutions) {
    if (typeof mediaCsid === 'undefined') {
      const institutions = holdingInstitutions.filter(value => !!value);

      if (institutions.size > 0) {
        const findImage = institutions.reduce((promise, institution) => promise.catch(() => {
          const instShortId = (0, _cspaceRefname.getItemShortID)(institution);

          const instGatewayUrl = _config.default.get(['institutions', instShortId, 'gatewayUrl']);

          const instIndexName = _config.default.get(['institutions', instShortId, 'esIndexName']);

          if (!instGatewayUrl) {
            return Promise.reject();
          }

          return this.getMediaCsid(instGatewayUrl, instIndexName, referenceValue).then(instMediaCsid => {
            if (!instMediaCsid) {
              return Promise.reject();
            }

            return Promise.resolve({
              instGatewayUrl,
              instMediaCsid
            });
          });
        }), Promise.reject());
        findImage.then(({
          instGatewayUrl,
          instMediaCsid
        }) => {
          this.setState({
            gatewayUrl: instGatewayUrl,
            mediaCsid: instMediaCsid
          });
        }).catch(() => {});
      } else {
        this.setState({
          mediaCsid: null
        });
      }
    }
  }

  render() {
    const {
      gatewayUrl,
      mediaCsid
    } = this.state;

    if (mediaCsid === null) {
      return /*#__PURE__*/_react.default.createElement("div", {
        "aria-hidden": true,
        className: _SearchResultImage.default.noimage
      }, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.noimage));
    }

    const imageUrl = mediaCsid && (0, _urlHelpers.blobUrl)(gatewayUrl, mediaCsid, _config.default.get('searchResultImageDerivative'));
    let style;

    if (imageUrl) {
      style = {
        backgroundImage: `url(${imageUrl})`
      };
    }

    return /*#__PURE__*/_react.default.createElement("div", {
      className: _SearchResultImage.default.common,
      style: style
    });
  }

}

exports.default = SearchResultImage;
SearchResultImage.propTypes = propTypes;
SearchResultImage.defaultProps = defaultProps;