"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _immutable = _interopRequireDefault(require("immutable"));

var _SearchParamList = _interopRequireDefault(require("./SearchParamList"));

var _SearchResultList = _interopRequireDefault(require("./SearchResultList"));

var _SearchResultStats = _interopRequireDefault(require("./SearchResultStats"));

var _SortSelectContainer = _interopRequireDefault(require("../entry/SortSelectContainer"));

var _ids = require("../../../constants/ids");

var _SearchResultPanel = _interopRequireDefault(require("../../../../styles/cspace/SearchResultPanel.css"));

var _dimensions = _interopRequireDefault(require("../../../../styles/dimensions.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/* global window */
const propTypes = {
  error: _propTypes.default.instanceOf(Error),
  isPending: _propTypes.default.bool,
  offset: _propTypes.default.number,
  onHitsUpdated: _propTypes.default.func,
  result: _propTypes.default.instanceOf(_immutable.default.Map),
  params: _propTypes.default.instanceOf(_immutable.default.Map),
  search: _propTypes.default.func,
  setSearchPageSize: _propTypes.default.func
};
const defaultProps = {
  error: undefined,
  isPending: false,
  offset: undefined,
  onHitsUpdated: undefined,
  params: _immutable.default.Map(),
  result: undefined,
  search: () => undefined,
  setSearchPageSize: () => undefined
};
const {
  searchResultTileWidth: cssTileWidth,
  searchResultTileBodyHeight: cssTileBodyHeight
} = _dimensions.default;
const tileWidth = parseInt(cssTileWidth, 10);
const tileBodyHeight = parseInt(cssTileBodyHeight, 10);
const tileHeight = tileWidth + tileBodyHeight;

const calculateSearchPageSize = () => {
  const width = window.innerWidth;
  const height = window.innerHeight;
  const ratio = window.devicePixelRatio || 1;
  const pageSize = width / tileWidth * (height / tileHeight + 2) / ratio;
  return Math.max(Math.ceil(pageSize), 12);
};

class SearchResultPanel extends _react.Component {
  constructor() {
    super();
    this.handleScroll = this.handleScroll.bind(this);
    this.ref = /*#__PURE__*/_react.default.createRef();
  }

  componentDidMount() {
    const {
      setSearchPageSize
    } = this.props;
    window.addEventListener('scroll', this.handleScroll, false);
    setSearchPageSize(calculateSearchPageSize());
    this.search();
  }

  componentDidUpdate(prevProps) {
    const {
      params
    } = this.props;
    const {
      params: prevParams
    } = prevProps;

    if (params !== prevParams) {
      this.search();
    }
  }

  componentWillUnmount() {
    window.removeEventListener('scroll', this.handleScroll, false);
  }

  handleScroll() {
    const {
      search
    } = this.props;
    const rect = this.ref.current.getBoundingClientRect();
    const bottomOffset = rect.bottom - window.innerHeight;

    if (bottomOffset <= tileHeight) {
      search();
    }
  }

  search() {
    const {
      search
    } = this.props;
    search();
  }

  renderError() {
    const {
      error
    } = this.props;
    return /*#__PURE__*/_react.default.createElement("div", null, error.message);
  }

  renderResult() {
    const {
      isPending,
      offset,
      onHitsUpdated,
      params,
      result
    } = this.props;
    return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("header", null, /*#__PURE__*/_react.default.createElement(_SearchParamList.default, {
      params: params
    }), /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement(_SearchResultStats.default, {
      count: result && result.get('total')
    }), /*#__PURE__*/_react.default.createElement(_SortSelectContainer.default, {
      value: params.get(_ids.SORT_ID)
    }))), /*#__PURE__*/_react.default.createElement(_SearchResultList.default, {
      isPending: isPending,
      offset: offset,
      onHitsUpdated: onHitsUpdated,
      params: params,
      hits: result && result.get('hits')
    }));
  }

  render() {
    const {
      error
    } = this.props;
    return /*#__PURE__*/_react.default.createElement("div", {
      className: _SearchResultPanel.default.common,
      ref: this.ref
    }, error ? this.renderError() : this.renderResult());
  }

}

exports.default = SearchResultPanel;
SearchResultPanel.propTypes = propTypes;
SearchResultPanel.defaultProps = defaultProps;